declare interface IClassNameProps {
    /**
     * Defines the container styles & layout
     */
    className?: string
}

declare interface IChildrenProps {
    /**
     * Defines the Children DOM for any react component
     */
    children?: ReactNode | ReactChildren
}

/**
 * Defines standard orientations
 */
declare enum Orientation {
    'horizontal',
    'vertical',
}

/**
 * Defines default sizes
 */
declare enum Sizes {
    'xs',
    'sm', //24
    'md', //32
    'lg', //40
    'xl',
}

/**
 * Defines default button sizes
 */
declare enum ButtonSizes {
    'sm', //24
    'md', //32
    'lg', //40
    'xl', //56
}

/**
 * Defines available color themes
 */
declare enum Variant {
    'primary' = 'primary',
    'secondary' = 'secondary',
    'ghost' = 'ghost',
    'danger' = 'danger',
    'white' = 'white',
}

declare interface IOptionProps {
    /**
     * Defines the avatar background color
     */
    avatarColor?: string
    /**
     * Defines the group it belongs to
     */
    group?: string
    /**
     * Defines the option unique id
     */
    id?: string | number
    /**
     * Defines the display label of an option
     */
    label?: string
    /**
     * Defines the leading icon of the option item
     */
    leadingIcon?: string
    /**
     * Defines the display label of an option
     */
    name?: string
    /**
     * Defines the avatar text color
     */
    textColor?: string
    /**
     * Defines the value of an option
     */
    value?: string
}

declare type INote<T = any> = T & {
    description: string
    id: string
    isArchived: boolean
    parentId: string
    priority: Priority
    subNotes: INote<T>[]
    title?: string
    updatedBy?: string
    updatedDate?: string
    userName: string
    userList?: any[]
}

/**
 * Defines the string type
 */
declare type IString = string | undefined

declare type ImpactType = 'bio' | 'carbon' | 'eutro' | 'water'

declare type Priority = 'High' | 'Medium' | 'Low' | 'None'

declare type NoteType = 'Hotspot' | 'Insight' | 'Note'

declare type OptionLabelKey = 'label' | 'name' | 'value'

export {
    IClassNameProps,
    IChildrenProps,
    IOptionProps,
    OptionLabelKey,
    INote,
    Orientation,
    Priority,
    Sizes,
    IString,
    Variant,
    ImpactType,
    ButtonSizes,
    NoteType,
}
